Installation
============

Install the plugin using `pip`:

.. code-block:: shell

   $ pip install sphinx-click

Alternatively, install from source by cloning this repo then running
`setup.py`:

.. code-block:: shell

   $ python setup.py install

.. important::

   Both the package you're referencing and any dependencies **must be
   installed**.
